@@ -1,5 +1,5 @@
 // -*- c++ -*-
-/* $Id: object.cc,v 1.4 2004/03/13 15:20:16 murrayc Exp $ */
+/* $Id: object.cc,v 1.5 2004/05/13 15:40:05 daniel Exp $ */
 
 /* Copyright 1998-2002 The gtkmm Development Team
  *
@@ -129,16 +129,6 @@ ConstructParams::ConstructParams(const Glib::Class& glibmm_class_,
   va_end(var_args);
 }
 
-ConstructParams::ConstructParams(const ConstructParams& src)
-: glibmm_class(src.glibmm_class),
-  n_parameters(src.n_parameters),
-  parameters(src.parameters)
-{
-  //This is only used by the C++ compiler (since g++ 3.4) to create temporary instances.
-  //Apparently the compiler will actually optimize away the use of this.
-  //See bug #132300.
-}
-
 ConstructParams::~ConstructParams()
 {
   while(n_parameters > 0)
@@ -147,6 +137,24 @@ ConstructParams::~ConstructParams()
   g_free(parameters);
 }
 
+ConstructParams::ConstructParams(const ConstructParams& other)
+:
+  glibmm_class  (other.glibmm_class),
+  n_parameters  (other.n_parameters),
+  parameters    (g_new(GParameter, n_parameters))
+{
+  for (unsigned int i = 0; i < n_parameters; ++i)
+  {
+    GParameter& param = parameters[i];
+
+    param.name = other.parameters[i].name;
+    param.value.g_type = 0;
+
+    g_value_init(&param.value, G_VALUE_TYPE(&other.parameters[i].value));
+    g_value_copy(&other.parameters[i].value, &param.value);
+  }
+}
+
 
 /**** Glib::Object_Class ***************************************************/
 
