@@ -187,23 +187,27 @@ sub output_wrap_default_signal_handler_h($$$$$$)
 }
 
 # _SIGNAL_CC(signame, gtkname, rettype, crettype,`<cppargs>',`<cargs>')
-sub output_wrap_default_signal_handler_cc($$$$$$)
+sub output_wrap_default_signal_handler_cc($$$$$$$$)
 {
-  my ($self, $filename, $line_num, $objCppfunc, $objDefsSignal, $bImplement, $bCustomCCallback) = @_;
+  my ($self, $filename, $line_num, $objCppfunc, $objDefsSignal, $bImplement, $bCustomCCallback, $bRefreturn) = @_;
   my $cname = $$objDefsSignal{name};
   # $cname = $1 if ($args[3] =~ /"(.*)"/); #TODO: What's this about?
 
   # e.g. Gtk::Button::on_clicked:
   if($bImplement eq 1)
   {
-    my $str = sprintf("_SIGNAL_CC(%s,%s,%s,%s,\`%s\',\`%s\',%s)dnl\n",
+    my $refreturn = "";
+    $refreturn = "refreturn" if($bRefreturn eq 1);
+  
+    my $str = sprintf("_SIGNAL_CC(%s,%s,%s,%s,\`%s\',\`%s\',%s, %s)dnl\n",
       $$objCppfunc{name},
       $cname,
       $$objCppfunc{rettype},
       $$objDefsSignal{rettype},
       $objCppfunc->args_types_and_names(),
       convert_args_cpp_to_c($objCppfunc, $objDefsSignal, 0, $line_num), #$objCppfunc->args_names_only(),
-      $$objCppfunc{const});
+      $$objCppfunc{const},
+      $refreturn);
     $self->append($str);
   }
 
@@ -476,11 +480,14 @@ sub output_wrap_property($$$$$$)
     {
        $proxy_suffix = "_ReadOnly";
     }
-    
-    $name =~ s/-/_/g;
 
-    my $str = sprintf("_PROPERTY_PROXY(%s,%s,%s)dnl\n",
+    # Convert - to _ so we can use it in C++ method and variable names:
+    my $name_underscored = $name;
+    $name_underscored =~ s/-/_/g;
+
+    my $str = sprintf("_PROPERTY_PROXY(%s,%s,%s,%s)dnl\n",
       $name,
+      $name_underscored,
       $cpp_type,
       $proxy_suffix
     );
@@ -490,8 +497,9 @@ sub output_wrap_property($$$$$$)
     # If the property is not already read-only, then add a second const accessor for a read-only propertyproxy:
     if($proxy_suffix ne "_ReadOnly")
     {
-      my $str = sprintf("_PROPERTY_PROXY(%s,%s,%s)dnl\n",
+      my $str = sprintf("_PROPERTY_PROXY(%s,%s,%s,%s)dnl\n",
         $name,
+        $name_underscored,
         $cpp_type,
         "_ReadOnly"
       );
